@@ -1,7 +1,9 @@
-"""
-AUTHOR
-    Artur Barseghyan (artur.barseghyan@gmail.com)
-"""
+__title__ = 'admin_timeline.conf'
+__version__ = '0.5'
+__build__ = 0x000005
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('get_setting',)
+
 from django.conf import settings
 
 from admin_timeline import defaults
