@@ -1,5 +1,8 @@
-# @package django-admin-timeline
-# @author: Artur Barseghyan (artur.barseghyan@gmail.com)
+__title__ = 'admin_timeline.templatetags.admin_timeline_tags'
+__version__ = '0.5'
+__build__ = 0x000005
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('assign',)
 
 from django import template
 
