@@ -1,8 +1,7 @@
+__all__ = ('urlpatterns',)
+
 from django.conf.urls.defaults import *
 
 urlpatterns = patterns('admin_timeline.views',
-    url(r'^$',
-        view='log',
-        name='admin_timeline.log',
-    ),
+    url(r'^$', view='log', name='admin_timeline.log'),
 )
